@@ -14,6 +14,15 @@ var addOperatorScenarios = []expressionScenario{
 			"D0, P[1 a], (!!int)::3\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `[[c], [b]]`,
+		expression: `.[] | . += "a"`,
+		expected: []string{
+			"D0, P[0], (!!seq)::[c, a]\n",
+			"D0, P[1], (!!seq)::[b, a]\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `{}`,
