@@ -93,6 +93,15 @@ var multiplyOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::sample:\n    - &a\n    - !!merge <<: *a\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `[[c], [b]]`,
+		expression: `.[] | . *+ ["a"]`,
+		expected: []string{
+			"D0, P[0], (!!seq)::[c, a]\n",
+			"D0, P[1], (!!seq)::[b, a]\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   docWithHeader,
