@@ -5,6 +5,40 @@ import (
 )
 
 var stringsOperatorScenarios = []expressionScenario{
+	{
+		description:    "To up (upper) case",
+		subdescription: "Works with unicode characters",
+		document:       `água`,
+		expression:     "upcase",
+		expected: []string{
+			"D0, P[], (!!str)::ÁGUA\n",
+		},
+	},
+	{
+		skipDoc:    true,
+		document:   `!camel água`,
+		expression: "upcase",
+		expected: []string{
+			"D0, P[], (!camel)::ÁGUA\n",
+		},
+	},
+	{
+		description:    "To down (lower) case",
+		subdescription: "Works with unicode characters",
+		document:       `ÁgUA`,
+		expression:     "downcase",
+		expected: []string{
+			"D0, P[], (!!str)::água\n",
+		},
+	},
+	{
+		skipDoc:    true,
+		document:   `!camel ÁgUA`,
+		expression: "downcase",
+		expected: []string{
+			"D0, P[], (!camel)::água\n",
+		},
+	},
 	{
 		description: "Join strings",
 		document:    `[cat, meow, 1, null, true]`,
@@ -13,6 +47,14 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!str)::cat; meow; 1; ; true\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `[!horse cat, !goat meow, !frog 1, null, true]`,
+		expression: `join("; ")`,
+		expected: []string{
+			"D0, P[], (!!str)::cat; meow; 1; ; true\n",
+		},
+	},
 	{
 		description: "Match string",
 		document:    `foo bar foo`,
@@ -21,6 +63,14 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[], ()::string: foo\noffset: 0\nlength: 3\ncaptures: []\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `!horse foo bar foo`,
+		expression: `match("foo")`,
+		expected: []string{
+			"D0, P[], ()::string: foo\noffset: 0\nlength: 3\ncaptures: []\n",
+		},
+	},
 	{
 		description: "Match string, case insensitive",
 		document:    `foo bar FOO`,
@@ -53,6 +103,14 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[], ()::a: xyzzy\nn: \"14\"\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `!horse xyzzy-14`,
+		expression: `capture("(?P<a>[a-z]+)-(?P<n>[0-9]+)")`,
+		expected: []string{
+			"D0, P[], ()::a: xyzzy\nn: \"14\"\n",
+		},
+	},
 	{
 		skipDoc:     true,
 		description: "Capture named groups into a map, with null",
@@ -78,6 +136,14 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::- string: cat\n  offset: 0\n  length: 3\n  captures: []\n- string: cat\n  offset: 4\n  length: 3\n  captures: []\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `!horse cat cat`,
+		expression: `[match("cat"; "g")]`,
+		expected: []string{
+			"D0, P[], (!!seq)::- string: cat\n  offset: 0\n  length: 3\n  captures: []\n- string: cat\n  offset: 4\n  length: 3\n  captures: []\n",
+		},
+	},
 	{
 		skipDoc:     true,
 		description: "No match",
@@ -107,6 +173,15 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[1], (!!bool)::false\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `[!horse "cat", !cat "dog"]`,
+		expression: `.[] | test("at")`,
+		expected: []string{
+			"D0, P[0], (!!bool)::true\n",
+			"D0, P[1], (!!bool)::false\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `["cat*", "cat*", "cat"]`,
@@ -135,6 +210,15 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::a: cart\nb: heart\n",
 		},
 	},
+	{
+		description:    "Custom types: that are really strings",
+		subdescription: "When custom tags are encountered, yq will try to decode the underlying type.",
+		document:       "a: !horse cat\nb: !goat heat",
+		expression:     `.[] |= sub("(a)", "${1}r")`,
+		expected: []string{
+			"D0, P[], (doc)::a: !horse cart\nb: !goat heart\n",
+		},
+	},
 	{
 		description: "Split strings",
 		document:    `"cat; meow; 1; ; true"`,
@@ -151,6 +235,14 @@ var stringsOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::- word\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `!horse "word"`,
+		expression: `split("; ")`,
+		expected: []string{
+			"D0, P[], (!!seq)::- word\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `""`,
